@@ -42,7 +42,7 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
                 test_loader_name=None, fixture_module=None,
                 response_handlers=None, content_handlers=None,
                 prefix='', require_ssl=False, url=None,
-                inner_fixtures=None):
+                inner_fixtures=None, verbose=False):
     """Read YAML files from a directory to create tests.
 
     Each YAML file represents an ordered sequence of HTTP requests.
@@ -64,21 +64,24 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
     :param require_ssl: If ``True``, make all tests default to using SSL.
     :param inner_fixtures: A list of ``Fixtures`` to use with each
                            individual test request.
+    :param verbose: If ``True`` or ``'all'``, make tests verbose by default
+                    ``'headers'`` and ``'body'`` are also accepted.
     :type inner_fixtures: List of fixtures.Fixture classes.
     :rtype: TestSuite containing multiple TestSuites (one for each YAML file).
     """
 
-    # Exit immediately if we have no host to access, either via a real host
-    # or an intercept.
-    if not bool(host) ^ bool(intercept):
-        raise AssertionError('must specify exactly one of host or intercept')
-
     # If url is being used, reset host, port and prefix.
     if url:
         host, port, prefix, force_ssl = utils.host_info_from_target(url)
         if force_ssl and not require_ssl:
             require_ssl = force_ssl
 
+    # Exit immediately if we have no host to access, either via a real host
+    # or an intercept.
+    if not bool(host) ^ bool(intercept):
+        raise AssertionError(
+            'must specify exactly one of host or url, or intercept')
+
     # If the client has not provided a name to use as our base,
     # create one so that tests are effectively namespaced.
     if test_loader_name is None:
@@ -117,6 +120,12 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
             else:
                 suite_dict['defaults'] = {'ssl': True}
 
+        if any((verbose == opt for opt in [True, 'all', 'headers', 'body'])):
+            if 'defaults' in suite_dict:
+                suite_dict['defaults']['verbose'] = verbose
+            else:
+                suite_dict['defaults'] = {'verbose': verbose}
+
         file_suite = suitemaker.test_suite_from_dict(
             loader, test_base_name, suite_dict, path, host, port,
             fixture_module, intercept, prefix=prefix,
